@@ -86,10 +86,12 @@ class TestConfig:
         # What is the wordsize (in bits) of this platform?
         self.wordsize = ''
 
+        # Is tables next to code enabled?
+        self.tables_next_to_code = True
         # Verbosity level
         self.verbose = 2
 
-        # See Note [validate and testsuite speed] in toplevel Makefile.
+        # See Note [validate and testsuite speed] in `validate`
         self.speed = 1
 
         self.list_broken = False
@@ -172,7 +174,6 @@ class TestConfig:
 
         # threads
         self.threads = 1
-        self.use_threads = False
 
         # tests which should be considered to be broken during this testsuite
         # run.
@@ -234,8 +235,7 @@ def getConfig():
     return config
 
 import os
-# Hold our modified GHC testrunning environment so we don't poison the current
-# python's environment.
+# This is the environment in which we run test subprocesses.
 global ghc_env
 ghc_env = os.environ.copy()
 
