@@ -1,7 +1,7 @@
 {-# LANGUAGE GADTs, TypeOperators #-}
 module T15209 where
 
-import GHC.Prim
+import GHC.Exts
 
 foo :: a ~# Int -> ()
 foo = ()
